#! /bin/sh
# Remember that bash is compatible with sh
# Copyright (C) 2002 Ricardo Martins <rmartins@dcc.online.pt>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# This script patches SANE source tree to add the hp3500/hp4400c backend
#
# $Id: patch-sane.sh,v 2.4 2004/11/21 Johannes Hub

# Tests for number of arguments
if [ $# -ne 1 ]
    then
    echo "Usage: $0 [PATH_TO_SANE_DIR]"
    exit
fi

sane=$1

evaluate_retval()
{
    if [ $? = 0 ]
        then
	echo -e "\\033[50G"DONE
    else
	echo -e "\\033[50G"FAILED
	exit 1
    fi
}

# Files that belong to the hp35x0c/hp44x0c backend
hp_rts_files="hp_rts88xx.c \
hp_rts88xx.h \
hp_rts_35x0c.h \
hp_rts_35x0c.c \
hp_rts_44x0c.h \
hp_rts_44x0c.c \
hp_rts_xfer.c \
hp_rts_xfer.h \
hp_rts88xx.conf"

# Adds hp_rts (hp4470c) files to sane tree
echo "Adding new files to the SANE source tree..."

for file in $hp_rts_files
  do
  cp -v ./$file $sane/backend/ 
  #echo "copy file $file to $sane/backend/$file"
done
cp ./sane-hp_rts88xx.man $sane/doc/
cp ./hp_rts88xx.desc $sane/doc/descriptions/
#evaluate_retval

# Sees if SANE was already patched
if [ -e $sane/.hp_rts88xx ]
    then
    echo "BREAK: $1 appears to have already been patched..."
    exit 1
fi

touch $sane/.hp_rts88xx # to mark SANE as patched

# Modifies the Makefile.in files (this is hairy stuff)
echo -n "Modifying doc/Makefile.in..."
sed "s/sane-dll.5/& sane-hp_rts88xx.5/g" $sane/doc/Makefile.in | \
    sed "s/sane-dll.man/& sane-hp_rts88xx.man/g" > $sane/doc/tmp~
evaluate_retval

echo -n "Modifying backend/Makefile.in..."
sed "s/PRELOADABLE_BACKENDS =/& hp_rts88xx /g" $sane/backend/Makefile.in | \
    sed "s/DISTFILES = /& hp_rts88xx.c hp_rts88xx.h /g"  | \
        sed 's%libsane-abaton.la: ../sanei/sanei_scsi.lo%& \
libsane-hp_rts88xx.la: ../sanei/sanei_config2.lo \
libsane-hp_rts88xx.la: ../sanei/sanei_constrain_value.lo \
libsane-hp_rts88xx.la: ../sanei/sanei_usb.lo%' >  $sane/backend/tmp~
evaluate_retval

echo -n "Relocating files..."
mv $sane/doc/tmp~ $sane/doc/Makefile.in
mv $sane/backend/tmp~ $sane/backend/Makefile.in
evaluate_retval

# Adds a line with 'hp_rts88xx' to dll.conf
echo -n "Modifying backend/dll.conf..."
if [ -z $(grep hp_rts88xx $sane/backend/dll.conf) ]
    then
    echo "hp_rts88xx" >> $sane/backend/dll.conf
fi
evaluate_retval

echo "SANE patched with success!"
exit 0
